@@ -1,6 +1,6 @@
 ;;; gnorb-gnus.el --- The gnus-centric fuctions of gnorb -*- lexical-binding: t -*-
 
-;; Copyright (C) 2014  Free Software Foundation, Inc.
+;; Copyright (C) 2018  Free Software Foundation, Inc.
 
 ;; Author: Eric Abrahamsen <eric@ericabrahamsen.net>
 ;; Keywords:
@@ -687,6 +687,67 @@ reply."
   (add-to-list 'gnus-registry-extra-entries-precious 'org-tags)
   (add-to-list 'gnus-registry-track-extra 'org-tags))
 
+(defvar gnorb-registry-search-history nil)
+
+;;;###autoload
+(defun gnorb-gnus-search-registry (search-string)
+  "Search for and display messages using the registry.
+Prompt for a registry-specific SEARCH-STRING, then create an
+ephemeral group containing the resulting messages.  All tracked
+registry data keys are acceptable, see (slot-value
+gnus-registry-db 'tracked).  Unknown keys will be ignored.  Keys
+and search strings should be given as \"key:value\", with extra
+quotes around multi-word search values.  Eg:
+
+sender:google.com subject:\"your search results\""
+  (interactive
+   (list (read-string "Registry search terms: " nil
+		      gnorb-registry-search-history)))
+  (let (parsed found this-pass term)
+    (with-temp-buffer
+      (insert search-string)
+      (goto-char (point-min))
+      (while (re-search-forward
+	      "\\([[:alpha:]]+\\):\\(\\(?:\\w+\\|\"[[:alpha:] ]+\"\\)\\)"
+	      (point-at-eol) t)
+	(push (cons (intern (match-string 1))
+		    (string-trim (match-string 2) "\"" "\""))
+	      parsed))
+      (dolist (sym (slot-value gnus-registry-db 'tracked))
+	(when (setq term (cdr-safe (assoc sym parsed)))
+	  (maphash
+	   (lambda (k v)
+	     (when (string-match-p term k)
+	       (setq this-pass (append v this-pass))))
+	   (gethash sym (slot-value gnus-registry-db 'tracker)))
+	  (setq found (if found
+			  (seq-intersection found this-pass)
+			this-pass)
+		this-pass nil)))
+      (if found
+	  (let* ((server (gnorb-gnus-find-gnorb-server))
+		 (artlist
+		  (mapcar
+		   (lambda (msg)
+		     (pcase-let ((`(,group . ,artno) (gnorb-msg-id-request-head
+						      msg)))
+		       (when (and artno (integerp artno) (> artno 0))
+			 (vector group artno 100))))
+		   (delq nil (delete-dups found))))
+		 (name (make-temp-name "registry messages"))
+		 (spec (list
+			(cons 'nnir-specs (list (cons 'nnir-query-spec
+						      `((query . "dummy")
+							(articles . ,artlist)))
+						(cons 'nnir-group-spec
+						      `((,server ,(list name))))))
+			(cons 'nnir-artlist nil))))
+	    (switch-to-buffer gnus-group-buffer)
+	    (gnus-group-read-ephemeral-group
+	     name `(nnir ,server) nil `(switch-to-buffer ,gnus-group-buffer)
+	     nil nil spec))
+	(message "No results found")))))
+
 ;;;###autoload
 (defun gnorb-gnus-tag-message (arg &optional tags)
   "Tag message or messages with TAGS.
@@ -807,20 +868,7 @@ HEAD-TEXT, if present, as its name.  Otherwise create an
 ephemeral one, with RET as the value of its quit-config."
   (interactive)
   (require 'nnir)
-  (let* ((nnir-address
-	  (or (catch 'found
-		;; Try very hard to find the server.
-		(when (assoc 'nngnorb gnus-secondary-select-methods)
-		  (throw 'found
-			 (format
-			  "nngnorb:%s"
-			  (nth 1 (assoc 'nngnorb
-					gnus-secondary-select-methods)))))
-		(dolist (s (append gnus-server-alist gnus-server-method-cache))
-		  (when (eq 'nngnorb (cadr s))
-		    (throw 'found (car s)))))
-	      (user-error
-	       "Please add a \"nngnorb\" backend to your gnus installation.")))
+  (let* ((nnir-address (gnorb-gnus-find-gnorb-server))
 	 (name (if persist
 		   (read-string
 		    (format "Name for group (default %s): " head-text)
@@ -840,6 +888,25 @@ ephemeral one, with RET as the value of its quit-config."
 	  (gnus-group-select-group))
       (gnus-group-read-ephemeral-group name method nil ret nil nil spec))))
 
+(defun gnorb-gnus-find-gnorb-server (&optional no-error)
+  "Try very hard to find a local nngnorb server.
+If NO-ERROR is non-nil, return nil on failure, otherwise an
+error."
+  (or (catch 'found
+	;; Try very hard to find the server.
+	(when (assoc 'nngnorb gnus-secondary-select-methods)
+	  (throw 'found
+		 (format
+		  "nngnorb:%s"
+		  (nth 1 (assoc 'nngnorb
+				gnus-secondary-select-methods)))))
+	(dolist (s (append gnus-server-alist gnus-server-method-cache))
+	  (when (eq 'nngnorb (cadr s))
+	    (throw 'found (car s)))))
+      (unless no-error
+	(user-error
+	 "Please add a \"nngnorb\" backend to your gnus installation."))))
+
 (defun gnorb-gnus-summary-mode-hook ()
   "Check if we've entered a Gnorb-generated group, and activate
   `gnorb-summary-minor-mode', if so."
@@ -908,10 +975,10 @@ option `gnorb-gnus-hint-relevant-article' is non-nil."
 	      (t " ")))
     " "))
 
-(fset (intern (concat "gnus-user-format-function-"
-		      gnorb-gnus-summary-mark-format-letter))
-      (lambda (header)
-	(gnorb-gnus-insert-format-letter-maybe header)))
+(defalias (intern (concat "gnus-user-format-function-"
+			  gnorb-gnus-summary-mark-format-letter))
+  (lambda (header)
+    (gnorb-gnus-insert-format-letter-maybe header)))
 
 (defun gnorb-gnus-insert-format-tags (header)
   (let* ((id (mail-header-message-id header))
@@ -924,10 +991,10 @@ option `gnorb-gnus-hint-relevant-article' is non-nil."
 	 ":" (mapconcat #'identity tags ":") ":")
       "")))
 
-(fset (intern (concat "gnus-user-format-function-"
-		      gnorb-gnus-summary-tags-format-letter))
-      (lambda (header)
-	(gnorb-gnus-insert-format-tags header)))
+(defalias (intern (concat "gnus-user-format-function-"
+			  gnorb-gnus-summary-tags-format-letter))
+  (lambda (header)
+    (gnorb-gnus-insert-format-tags header)))
 
 ;;;###autoload
 (defun gnorb-gnus-view ()
